@@ -1,6 +1,6 @@
 /* ChanServ core functions
  *
- * (C) 2003-2014 Anope Team
+ * (C) 2003-2016 Anope Team
  * Contact us at team@anope.org
  *
  * Please read COPYING and README for further details.
@@ -554,7 +554,11 @@ class CSAKick : public Module
 					mask = autokick->mask;
 				reason = autokick->reason;
 				if (reason.empty())
+				{
 					reason = Language::Translate(u, Config->GetModule(this)->Get<const Anope::string>("autokickreason").c_str());
+					reason = reason.replace_all_cs("%n", u->nick)
+							.replace_all_cs("%c", c->name);
+				}
 				if (reason.empty())
 					reason = Language::Translate(u, _("User has been banned from the channel"));
 				return EVENT_STOP;
