@@ -101,7 +101,7 @@ class CommandCSUp : public Command
 			}
 			else if (source.GetUser() && u != source.GetUser() && c->ci->HasExt("PEACE"))
 			{
-				if (c->ci->AccessFor(u) > c->ci->AccessFor(source.GetUser()))
+				if (c->ci->AccessFor(u) >= c->ci->AccessFor(source.GetUser()))
 				{
 					if (source.HasPriv("chanserv/administration"))
 						override = true;
@@ -199,7 +199,7 @@ class CommandCSDown : public Command
 			}
 			else if (source.GetUser() && u != source.GetUser() && c->ci->HasExt("PEACE"))
 			{
-				if (c->ci->AccessFor(u) > c->ci->AccessFor(source.GetUser()))
+				if (c->ci->AccessFor(u) >= c->ci->AccessFor(source.GetUser()))
 				{
 					if (source.HasPriv("chanserv/administration"))
 						override = true;
