@@ -76,7 +76,11 @@ class CommandOSChanKill : public Command
 					if (uc->user->server == Me || uc->user->HasMode("OPER"))
 						continue;
 
-					XLine *x = new XLine("*@" + uc->user->host, source.GetNick(), expires, realreason, XLineManager::GenerateUID());
+					Anope::string akillmask = "*@" + uc->user->host;
+					if (akills->HasEntry(akillmask))
+						continue;
+
+					XLine *x = new XLine(akillmask, source.GetNick(), expires, realreason, XLineManager::GenerateUID());
 					akills->AddXLine(x);
 					akills->OnMatch(uc->user, x);
 				}
