@@ -1,6 +1,6 @@
 /* OperServ core functions
  *
- * (C) 2003-2014 Anope Team
+ * (C) 2003-2016 Anope Team
  * Contact us at team@anope.org
  *
  * Please read COPYING and README for further details.
@@ -144,6 +144,7 @@ class CommandOSSXLineBase : public Command
 					entry["By"] = x->by;
 					entry["Created"] = Anope::strftime(x->created, NULL, true);
 					entry["Expires"] = Anope::Expires(x->expires, source.nc);
+					entry["ID"] = x->id;
 					entry["Reason"] = x->reason;
 					list.AddEntry(entry);
 				}
@@ -165,6 +166,7 @@ class CommandOSSXLineBase : public Command
 					entry["By"] = x->by;
 					entry["Created"] = Anope::strftime(x->created, NULL, true);
 					entry["Expires"] = Anope::Expires(x->expires, source.nc);
+					entry["ID"] = x->id;
 					entry["Reason"] = x->reason;
 					list.AddEntry(entry);
 				}
@@ -196,7 +198,11 @@ class CommandOSSXLineBase : public Command
 	void OnView(CommandSource &source, const std::vector<Anope::string> &params)
 	{
 		ListFormatter list(source.GetAccount());
-		list.AddColumn(_("Number")).AddColumn(_("Mask")).AddColumn(_("By")).AddColumn(_("Created")).AddColumn(_("Expires")).AddColumn(_("Reason"));
+		list.AddColumn(_("Number")).AddColumn(_("Mask")).AddColumn(_("By")).AddColumn(_("Created")).AddColumn(_("Expires"));
+		if (Config->GetModule("operserv")->Get<bool>("akillids"))
+			list.AddColumn(_("ID"));
+		list.AddColumn(_("Reason"));
+
 		this->ProcessList(source, params, list);
 	}
 
@@ -354,9 +360,7 @@ class CommandOSSNLine : public CommandOSSXLineBase
 		if (Config->GetModule("operserv")->Get<bool>("addakiller", "yes") && !source.GetNick().empty())
 			reason = "[" + source.GetNick() + "] " + reason;
 
-		if (!this->xlm()->CanAdd(source, mask, expires, reason))
-			return;
-		else if (mask.find_first_not_of("/.*?") == Anope::string::npos)
+		if (mask.find_first_not_of("/.*?") == Anope::string::npos)
 		{
 			source.Reply(USERHOST_MASK_TOO_WIDE, mask.c_str());
 			return;
@@ -380,6 +384,9 @@ class CommandOSSNLine : public CommandOSSXLineBase
 			return;
 		}
 
+		if (!this->xlm()->CanAdd(source, mask, expires, reason))
+			return;
+
 		EventReturn MOD_RESULT;
 		FOREACH_RESULT(OnAddXLine, MOD_RESULT, (source, x, this->xlm()));
 		if (MOD_RESULT == EVENT_STOP)
@@ -561,9 +568,7 @@ class CommandOSSQLine : public CommandOSSXLineBase
 		if (Config->GetModule("operserv")->Get<bool>("addakiller", "yes") && !source.GetNick().empty())
 			reason = "[" + source.GetNick() + "] " + reason;
 
-		if (!this->sqlines->CanAdd(source, mask, expires, reason))
-			return;
-		else if (mask.find_first_not_of("./?*") == Anope::string::npos)
+		if (mask.find_first_not_of("./?*") == Anope::string::npos)
 		{
 			source.Reply(USERHOST_MASK_TOO_WIDE, mask.c_str());
 			return;
@@ -587,6 +592,9 @@ class CommandOSSQLine : public CommandOSSXLineBase
 			return;
 		}
 
+		if (!this->sqlines->CanAdd(source, mask, expires, reason))
+			return;
+
 		EventReturn MOD_RESULT;
 		FOREACH_RESULT(OnAddXLine, MOD_RESULT, (source, x, this->xlm()));
 		if (MOD_RESULT == EVENT_STOP)
