@@ -23,8 +23,8 @@ class StatusUpdate : public Module
 			{
 				User *user = it->second->user;
 
-				ChanAccess::Path p;
-				if (user->server != Me && access->Matches(user, user->Account(), p))
+				ChannelInfo *next;
+				if (user->server != Me && access->Matches(user, user->Account(), next))
 				{
 					AccessGroup ag = ci->AccessFor(user);
 
@@ -46,8 +46,8 @@ class StatusUpdate : public Module
 			{
 				User *user = it->second->user;
 
-				ChanAccess::Path p;
-				if (user->server != Me && access->Matches(user, user->Account(), p))
+				ChannelInfo *next;
+				if (user->server != Me && access->Matches(user, user->Account(), next))
 				{
 					AccessGroup ag = ci->AccessFor(user);
 
