@@ -1,3 +1,11 @@
+/*
+ *
+ * (C) 2012-2016 Anope Team
+ * Contact us at team@anope.org
+ *
+ * Please read COPYING and README for further details.
+ */
+
 /* RequiredLibraries: tre */
 
 #include "module.h"
@@ -52,6 +60,26 @@ class ModuleRegexTRE : public Module
 	{
 		this->SetPermanent(true);
 	}
+
+	~ModuleRegexTRE()
+	{
+		for (std::list<XLineManager *>::iterator it = XLineManager::XLineManagers.begin(); it != XLineManager::XLineManagers.end(); ++it)
+		{
+			XLineManager *xlm = *it;
+			const std::vector<XLine *> &xlines = xlm->GetList();
+
+			for (unsigned int i = 0; i < xlines.size(); ++i)
+			{
+				XLine *x = xlines[i];
+
+				if (x->regex && dynamic_cast<TRERegex *>(x->regex))
+				{
+					delete x->regex;
+					x->regex = NULL;
+				}
+			}
+		}
+	}
 };
 
 MODULE_INIT(ModuleRegexTRE)
