@@ -97,7 +97,7 @@ class External : public Mechanism
 		}
 		else if (m.type == "C")
 		{
-			if (!certs)
+			if (!certs || mysess->cert.empty())
 			{
 				sasl->Fail(sess);
 				delete sess;
@@ -223,7 +223,18 @@ class SASLService : public SASL::Service, public Timer
 
 	void Succeed(Session *session, NickCore *nc) anope_override
 	{
-		IRCD->SendSVSLogin(session->uid, nc->display);
+		// If the user is already introduced then we log them in now.
+		// Otherwise, we send an SVSLOGIN to log them in later.
+		User *user = User::Find(session->uid);
+		NickAlias *na = NickAlias::Find(nc->display);
+		if (user)
+		{
+			user->Identify(na);
+		}
+		else
+		{
+			IRCD->SendSVSLogin(session->uid, nc->display, na->GetVhostIdent(), na->GetVhostHost());
+		}
 		this->SendMessage(session, "D", "S");
 	}
 
@@ -266,6 +277,21 @@ class ModuleSASL : public Module
 	Plain plain;
 	External *external;
 
+	std::vector<Anope::string> mechs;
+
+	void CheckMechs()
+	{
+		std::vector<Anope::string> newmechs = ::Service::GetServiceKeys("SASL::Mechanism");
+		if (newmechs == mechs)
+			return;
+
+		mechs = newmechs;
+
+		// If we are connected to the network then broadcast the mechlist.
+		if (Me && Me->IsSynced())
+			IRCD->SendSASLMechanisms(mechs);
+	}
+
  public:
 	ModuleSASL(const Anope::string &modname, const Anope::string &creator) : Module(modname, creator, VENDOR),
 		sasl(this), plain(this), external(NULL)
@@ -273,6 +299,7 @@ class ModuleSASL : public Module
 		try
 		{
 			external = new External(this);
+			CheckMechs();
 		}
 		catch (ModuleException &) { }
 	}
@@ -281,6 +308,22 @@ class ModuleSASL : public Module
 	{
 		delete external;
 	}
+
+	void OnModuleLoad(User *, Module *) anope_override
+	{
+		CheckMechs();
+	}
+
+	void OnModuleUnload(User *, Module *) anope_override
+	{
+		CheckMechs();
+	}
+
+	void OnPreUplinkSync(Server *) anope_override
+	{
+		// We have not yet sent a mechanism list so always do it here.
+		IRCD->SendSASLMechanisms(mechs);
+	}
 };
 
 MODULE_INIT(ModuleSASL)
