@@ -374,7 +374,7 @@ class UnrealIRCdProto : public IRCDProto
 		UplinkSocket::Message(BotInfo::Find(message.source)) << "SASL " << message.target.substr(0, p) << " " << message.target << " " << message.type << " " << message.data << (message.ext.empty() ? "" : " " + message.ext);
 	}
 
-	void SendSVSLogin(const Anope::string &uid, const Anope::string &acc) anope_override
+	void SendSVSLogin(const Anope::string &uid, const Anope::string &acc, const Anope::string &vident, const Anope::string &vhost) anope_override
 	{
 		size_t p = uid.find('!');
 		if (p == Anope::string::npos)
@@ -966,7 +966,11 @@ struct IRCDMessageNick : IRCDMessage
 			User::OnIntroduce(params[0], params[3], params[4], vhost, ip, s, params[10], user_ts, params[7], "", na ? *na->nc : NULL);
 		}
 		else
-			source.GetUser()->ChangeNick(params[0]);
+		{
+			User *u = source.GetUser();
+			if (u)
+				u->ChangeNick(params[0]);
+		}
 	}
 };
 
@@ -1279,7 +1283,7 @@ struct IRCDMessageUID : IRCDMessage
 
 		User *u = User::OnIntroduce(nickname, username, hostname, vhost, ip, source.GetServer(), info, user_ts, umodes, uid, na ? *na->nc : NULL);
 
-		if (!chost.empty() && chost != u->GetCloakedHost())
+		if (u && !chost.empty() && chost != u->GetCloakedHost())
 			u->SetCloakedHost(chost);
 	}
 };
