@@ -162,7 +162,7 @@ void Join::SJoin(MessageSource &source, const Anope::string &chan, time_t ts, co
 			c->Sync();
 
 			if (c->CheckDelete())
-				delete c;
+				c->QueueForDeletion();
 		}
 	}
 }
